# TensorMaps automatically generated by tensor_map_maker.py
# DO NOT EDIT

from ml4h.defines import StorageType
from ml4h.metrics import weighted_crossentropy
from ml4h.tensormap.ukb.demographics import prevalent_incident_tensor
from ml4h.TensorMap import TensorMap, Interpretation, make_range_validator



#  TensorMaps for MPG disease phenotypes
allergic_rhinitis = TensorMap('allergic_rhinitis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_allergic_rhinitis':0, 'allergic_rhinitis':1}, loss=weighted_crossentropy([1.0, 8], 'allergic_rhinitis'))
alzheimers_or_dementia = TensorMap('alzheimers_or_dementia', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_alzheimers_or_dementia':0, 'alzheimers_or_dementia':1}, loss=weighted_crossentropy([1.0, 658], 'alzheimers_or_dementia'))
amyotrophic_lateral_sclerosis = TensorMap('amyotrophic_lateral_sclerosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_amyotrophic_lateral_sclerosis':0, 'amyotrophic_lateral_sclerosis':1}, loss=weighted_crossentropy([1.0, 867], 'amyotrophic_lateral_sclerosis'))
anxiety = TensorMap('anxiety', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_anxiety':0, 'anxiety':1}, loss=weighted_crossentropy([1.0, 29], 'anxiety'))
aortic_regurgitation = TensorMap('aortic_regurgitation', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_aortic_regurgitation':0, 'aortic_regurgitation':1}, loss=weighted_crossentropy([1.0, 184], 'aortic_regurgitation'))
aortic_stenosis = TensorMap('aortic_stenosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_aortic_stenosis':0, 'aortic_stenosis':1}, loss=weighted_crossentropy([1.0, 107], 'aortic_stenosis'))
aortic_valve_disease = TensorMap('aortic_valve_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_aortic_valve_disease':0, 'aortic_valve_disease':1}, loss=weighted_crossentropy([1.0, 58], 'aortic_valve_disease'))
asthma = TensorMap('asthma', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_asthma':0, 'asthma':1}, loss=weighted_crossentropy([1.0, 3], 'asthma'))
atrial_fibrillation_or_flutter = TensorMap('atrial_fibrillation_or_flutter', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_atrial_fibrillation_or_flutter':0, 'atrial_fibrillation_or_flutter':1}, loss=weighted_crossentropy([1.0, 13], 'atrial_fibrillation_or_flutter'))
atrial_septal_defect_patent_foramen_ovale = TensorMap('atrial_septal_defect_patent_foramen_ovale', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_atrial_septal_defect_patent_foramen_ovale':0, 'atrial_septal_defect_patent_foramen_ovale':1}, loss=weighted_crossentropy([1.0, 425], 'atrial_septal_defect_patent_foramen_ovale'))
atrial_septal_defect_patent_foramen_ovale_v2 = TensorMap('atrial_septal_defect_patent_foramen_ovale_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_atrial_septal_defect_patent_foramen_ovale_v2':0, 'atrial_septal_defect_patent_foramen_ovale_v2':1}, loss=weighted_crossentropy([1.0, 425], 'atrial_septal_defect_patent_foramen_ovale_v2'))
back_pain = TensorMap('back_pain', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_back_pain':0, 'back_pain':1}, loss=weighted_crossentropy([1.0, 11], 'back_pain'))
bariatric_surgery = TensorMap('bariatric_surgery', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bariatric_surgery':0, 'bariatric_surgery':1}, loss=weighted_crossentropy([1.0, 330], 'bariatric_surgery'))
bariatric_surgery_v2 = TensorMap('bariatric_surgery_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bariatric_surgery_v2':0, 'bariatric_surgery_v2':1}, loss=weighted_crossentropy([1.0, 512], 'bariatric_surgery_v2'))
bipolar_disorder = TensorMap('bipolar_disorder', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bipolar_disorder':0, 'bipolar_disorder':1}, loss=weighted_crossentropy([1.0, 127], 'bipolar_disorder'))
bladder_cancer = TensorMap('bladder_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bladder_cancer':0, 'bladder_cancer':1}, loss=weighted_crossentropy([1.0, 89], 'bladder_cancer'))
bradyarrhythmia_av_block_or_distal_conduction_disease = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease':0, 'bradyarrhythmia_av_block_or_distal_conduction_disease':1}, loss=weighted_crossentropy([1.0, 40], 'bradyarrhythmia_av_block_or_distal_conduction_disease'))
bradyarrhythmia_av_block_or_distal_conduction_disease_hard = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_hard', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_hard':0, 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard':1}, loss=weighted_crossentropy([1.0, 70], 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard'))
bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2 = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2':0, 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2':1}, loss=weighted_crossentropy([1.0, 73], 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2'))
bradyarrhythmia_av_block_or_distal_conduction_disease_v2 = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_v2':0, 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2':1}, loss=weighted_crossentropy([1.0, 61], 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2'))
bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted':0, 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted':1}, loss=weighted_crossentropy([1.0, 266], 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted'))
bradyarrhythmia_general_inclusive_definition = TensorMap('bradyarrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_general_inclusive_definition':0, 'bradyarrhythmia_general_inclusive_definition':1}, loss=weighted_crossentropy([1.0, 26], 'bradyarrhythmia_general_inclusive_definition'))
bradyarrhythmia_only = TensorMap('bradyarrhythmia_only', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_only':0, 'bradyarrhythmia_only':1}, loss=weighted_crossentropy([1.0, 48], 'bradyarrhythmia_only'))
bradyarrhythmia_pacemaker = TensorMap('bradyarrhythmia_pacemaker', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_pacemaker':0, 'bradyarrhythmia_pacemaker':1}, loss=weighted_crossentropy([1.0, 52], 'bradyarrhythmia_pacemaker'))
bradyarrhythmia_pacemaker_v2 = TensorMap('bradyarrhythmia_pacemaker_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_pacemaker_v2':0, 'bradyarrhythmia_pacemaker_v2':1}, loss=weighted_crossentropy([1.0, 51], 'bradyarrhythmia_pacemaker_v2'))
bradyarrhythmia_sinus_node_dysfunction = TensorMap('bradyarrhythmia_sinus_node_dysfunction', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_sinus_node_dysfunction':0, 'bradyarrhythmia_sinus_node_dysfunction':1}, loss=weighted_crossentropy([1.0, 504], 'bradyarrhythmia_sinus_node_dysfunction'))
bradyarrhythmia_sinus_node_dysfunction_hard = TensorMap('bradyarrhythmia_sinus_node_dysfunction_hard', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_hard':0, 'bradyarrhythmia_sinus_node_dysfunction_hard':1}, loss=weighted_crossentropy([1.0, 733], 'bradyarrhythmia_sinus_node_dysfunction_hard'))
bradyarrhythmia_sinus_node_dysfunction_hard_v2 = TensorMap('bradyarrhythmia_sinus_node_dysfunction_hard_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_hard_v2':0, 'bradyarrhythmia_sinus_node_dysfunction_hard_v2':1}, loss=weighted_crossentropy([1.0, 747], 'bradyarrhythmia_sinus_node_dysfunction_hard_v2'))
bradyarrhythmia_sinus_node_dysfunction_v2 = TensorMap('bradyarrhythmia_sinus_node_dysfunction_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_v2':0, 'bradyarrhythmia_sinus_node_dysfunction_v2':1}, loss=weighted_crossentropy([1.0, 639], 'bradyarrhythmia_sinus_node_dysfunction_v2'))
bradyarrhythmia_sinus_node_dysfunction_v2_restricted = TensorMap('bradyarrhythmia_sinus_node_dysfunction_v2_restricted', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_v2_restricted':0, 'bradyarrhythmia_sinus_node_dysfunction_v2_restricted':1}, loss=weighted_crossentropy([1.0, 828], 'bradyarrhythmia_sinus_node_dysfunction_v2_restricted'))
bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical = TensorMap('bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical':0, 'bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical':1}, loss=weighted_crossentropy([1.0, 48], 'bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical'))
bradyarrrhythmia_general_inclusive_definition_clinical = TensorMap('bradyarrrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_bradyarrrhythmia_general_inclusive_definition_clinical':0, 'bradyarrrhythmia_general_inclusive_definition_clinical':1}, loss=weighted_crossentropy([1.0, 47], 'bradyarrrhythmia_general_inclusive_definition_clinical'))
breast_cancer = TensorMap('breast_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_breast_cancer':0, 'breast_cancer':1}, loss=weighted_crossentropy([1.0, 15], 'breast_cancer'))
cardiac_surgery = TensorMap('cardiac_surgery', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_cardiac_surgery':0, 'cardiac_surgery':1}, loss=weighted_crossentropy([1.0, 33], 'cardiac_surgery'))
cataract = TensorMap('cataract', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_cataract':0, 'cataract':1}, loss=weighted_crossentropy([1.0, 8], 'cataract'))
cervical_cancer = TensorMap('cervical_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_cervical_cancer':0, 'cervical_cancer':1}, loss=weighted_crossentropy([1.0, 117], 'cervical_cancer'))
cholelithiasis_or_gallstones = TensorMap('cholelithiasis_or_gallstones', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_cholelithiasis_or_gallstones':0, 'cholelithiasis_or_gallstones':1}, loss=weighted_crossentropy([1.0, 11], 'cholelithiasis_or_gallstones'))
chronic_kidney_disease = TensorMap('chronic_kidney_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_chronic_kidney_disease':0, 'chronic_kidney_disease':1}, loss=weighted_crossentropy([1.0, 36], 'chronic_kidney_disease'))
chronic_obstructive_pulmonary_disease = TensorMap('chronic_obstructive_pulmonary_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_chronic_obstructive_pulmonary_disease':0, 'chronic_obstructive_pulmonary_disease':1}, loss=weighted_crossentropy([1.0, 14], 'chronic_obstructive_pulmonary_disease'))
colorectal_cancer = TensorMap('colorectal_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_colorectal_cancer':0, 'colorectal_cancer':1}, loss=weighted_crossentropy([1.0, 50], 'colorectal_cancer'))
conduction_system_disease_only = TensorMap('conduction_system_disease_only', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_conduction_system_disease_only':0, 'conduction_system_disease_only':1}, loss=weighted_crossentropy([1.0, 49], 'conduction_system_disease_only'))
congenital_heart_disease = TensorMap('congenital_heart_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_congenital_heart_disease':0, 'congenital_heart_disease':1}, loss=weighted_crossentropy([1.0, 218], 'congenital_heart_disease'))
congenital_heart_disease_ebstein_anomaly = TensorMap('congenital_heart_disease_ebstein_anomaly', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_congenital_heart_disease_ebstein_anomaly':0, 'congenital_heart_disease_ebstein_anomaly':1}, loss=weighted_crossentropy([1.0, 14813], 'congenital_heart_disease_ebstein_anomaly'))
coronary_artery_disease = TensorMap('coronary_artery_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_coronary_artery_disease':0, 'coronary_artery_disease':1}, loss=weighted_crossentropy([1.0, 10], 'coronary_artery_disease'))
coronary_artery_disease_hard = TensorMap('coronary_artery_disease_hard', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_coronary_artery_disease_hard':0, 'coronary_artery_disease_hard':1}, loss=weighted_crossentropy([1.0, 9], 'coronary_artery_disease_hard'))
coronary_artery_disease_intermediate = TensorMap('coronary_artery_disease_intermediate', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_coronary_artery_disease_intermediate':0, 'coronary_artery_disease_intermediate':1}, loss=weighted_crossentropy([1.0, 7], 'coronary_artery_disease_intermediate'))
coronary_artery_disease_soft = TensorMap('coronary_artery_disease_soft', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_coronary_artery_disease_soft':0, 'coronary_artery_disease_soft':1}, loss=weighted_crossentropy([1.0, 5], 'coronary_artery_disease_soft'))
crohns_disease = TensorMap('crohns_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_crohns_disease':0, 'crohns_disease':1}, loss=weighted_crossentropy([1.0, 119], 'crohns_disease'))
death = TensorMap('death', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_death':0, 'death':1}, loss=weighted_crossentropy([1.0, 17], 'death'))
depression = TensorMap('depression', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_depression':0, 'depression':1}, loss=weighted_crossentropy([1.0, 6], 'depression'))
dermatitis = TensorMap('dermatitis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_dermatitis':0, 'dermatitis':1}, loss=weighted_crossentropy([1.0, 14], 'dermatitis'))
diabetes_all = TensorMap('diabetes_all', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_diabetes_all':0, 'diabetes_all':1}, loss=weighted_crossentropy([1.0, 7], 'diabetes_all'))
diabetes_type_1 = TensorMap('diabetes_type_1', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_diabetes_type_1':0, 'diabetes_type_1':1}, loss=weighted_crossentropy([1.0, 65], 'diabetes_type_1'))
diabetes_type_2 = TensorMap('diabetes_type_2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_diabetes_type_2':0, 'diabetes_type_2':1}, loss=weighted_crossentropy([1.0, 9], 'diabetes_type_2'))
diverticular_disease = TensorMap('diverticular_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_diverticular_disease':0, 'diverticular_disease':1}, loss=weighted_crossentropy([1.0, 7], 'diverticular_disease'))
enlarged_prostate = TensorMap('enlarged_prostate', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_enlarged_prostate':0, 'enlarged_prostate':1}, loss=weighted_crossentropy([1.0, 14], 'enlarged_prostate'))
epilepsy = TensorMap('epilepsy', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_epilepsy':0, 'epilepsy':1}, loss=weighted_crossentropy([1.0, 41], 'epilepsy'))
gastroesophageal_reflux_disease = TensorMap('gastroesophageal_reflux_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_gastroesophageal_reflux_disease':0, 'gastroesophageal_reflux_disease':1}, loss=weighted_crossentropy([1.0, 5], 'gastroesophageal_reflux_disease'))
glaucoma = TensorMap('glaucoma', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_glaucoma':0, 'glaucoma':1}, loss=weighted_crossentropy([1.0, 28], 'glaucoma'))
gout = TensorMap('gout', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_gout':0, 'gout':1}, loss=weighted_crossentropy([1.0, 27], 'gout'))
heart_failure = TensorMap('heart_failure', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_heart_failure':0, 'heart_failure':1}, loss=weighted_crossentropy([1.0, 32], 'heart_failure'))
heart_failure_v2 = TensorMap('heart_failure_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_heart_failure_v2':0, 'heart_failure_v2':1}, loss=weighted_crossentropy([1.0, 32], 'heart_failure_v2'))
hypercholesterolemia = TensorMap('hypercholesterolemia', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_hypercholesterolemia':0, 'hypercholesterolemia':1}, loss=weighted_crossentropy([1.0, 2], 'hypercholesterolemia'))
hypertension = TensorMap('hypertension', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_hypertension':0, 'hypertension':1}, loss=weighted_crossentropy([1.0, 1], 'hypertension'))
hyperthyroidism = TensorMap('hyperthyroidism', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_hyperthyroidism':0, 'hyperthyroidism':1}, loss=weighted_crossentropy([1.0, 44], 'hyperthyroidism'))
hypertrophic_cardiomyopathy = TensorMap('hypertrophic_cardiomyopathy', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_hypertrophic_cardiomyopathy':0, 'hypertrophic_cardiomyopathy':1}, loss=weighted_crossentropy([1.0, 679], 'hypertrophic_cardiomyopathy'))
hypothyroidism = TensorMap('hypothyroidism', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_hypothyroidism':0, 'hypothyroidism':1}, loss=weighted_crossentropy([1.0, 8], 'hypothyroidism'))
implantable_cardioverter_defibrillator = TensorMap('implantable_cardioverter_defibrillator', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_implantable_cardioverter_defibrillator':0, 'implantable_cardioverter_defibrillator':1}, loss=weighted_crossentropy([1.0, 328], 'implantable_cardioverter_defibrillator'))
inflammatory_bowel_disease = TensorMap('inflammatory_bowel_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_inflammatory_bowel_disease':0, 'inflammatory_bowel_disease':1}, loss=weighted_crossentropy([1.0, 37], 'inflammatory_bowel_disease'))
intervertebral_disc_displacement = TensorMap('intervertebral_disc_displacement', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_intervertebral_disc_displacement':0, 'intervertebral_disc_displacement':1}, loss=weighted_crossentropy([1.0, 21], 'intervertebral_disc_displacement'))
intracerebral_hemorrhage = TensorMap('intracerebral_hemorrhage', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_intracerebral_hemorrhage':0, 'intracerebral_hemorrhage':1}, loss=weighted_crossentropy([1.0, 234], 'intracerebral_hemorrhage'))
iron_deficiency_anemia = TensorMap('iron_deficiency_anemia', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_iron_deficiency_anemia':0, 'iron_deficiency_anemia':1}, loss=weighted_crossentropy([1.0, 20], 'iron_deficiency_anemia'))
irritable_bowel_syndrome = TensorMap('irritable_bowel_syndrome', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_irritable_bowel_syndrome':0, 'irritable_bowel_syndrome':1}, loss=weighted_crossentropy([1.0, 14], 'irritable_bowel_syndrome'))
ischemic_stroke = TensorMap('ischemic_stroke', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ischemic_stroke':0, 'ischemic_stroke':1}, loss=weighted_crossentropy([1.0, 50], 'ischemic_stroke'))
lung_cancer = TensorMap('lung_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_lung_cancer':0, 'lung_cancer':1}, loss=weighted_crossentropy([1.0, 87], 'lung_cancer'))
lupus_erythematosus = TensorMap('lupus_erythematosus', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_lupus_erythematosus':0, 'lupus_erythematosus':1}, loss=weighted_crossentropy([1.0, 268], 'lupus_erythematosus'))
migraine = TensorMap('migraine', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_migraine':0, 'migraine':1}, loss=weighted_crossentropy([1.0, 14], 'migraine'))
mitral_regurgitation = TensorMap('mitral_regurgitation', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_mitral_regurgitation':0, 'mitral_regurgitation':1}, loss=weighted_crossentropy([1.0, 89], 'mitral_regurgitation'))
mitral_stenosis = TensorMap('mitral_stenosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_mitral_stenosis':0, 'mitral_stenosis':1}, loss=weighted_crossentropy([1.0, 1269], 'mitral_stenosis'))
mitral_valve_disease = TensorMap('mitral_valve_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_mitral_valve_disease':0, 'mitral_valve_disease':1}, loss=weighted_crossentropy([1.0, 52], 'mitral_valve_disease'))
mitral_valve_prolapse = TensorMap('mitral_valve_prolapse', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_mitral_valve_prolapse':0, 'mitral_valve_prolapse':1}, loss=weighted_crossentropy([1.0, 373], 'mitral_valve_prolapse'))
multiple_sclerosis = TensorMap('multiple_sclerosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_multiple_sclerosis':0, 'multiple_sclerosis':1}, loss=weighted_crossentropy([1.0, 114], 'multiple_sclerosis'))
myocardial_infarction = TensorMap('myocardial_infarction', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_myocardial_infarction':0, 'myocardial_infarction':1}, loss=weighted_crossentropy([1.0, 13], 'myocardial_infarction'))
osteoarthritis = TensorMap('osteoarthritis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_osteoarthritis':0, 'osteoarthritis':1}, loss=weighted_crossentropy([1.0, 3], 'osteoarthritis'))
osteoporosis = TensorMap('osteoporosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_osteoporosis':0, 'osteoporosis':1}, loss=weighted_crossentropy([1.0, 18], 'osteoporosis'))
pancreatitis = TensorMap('pancreatitis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pancreatitis':0, 'pancreatitis':1}, loss=weighted_crossentropy([1.0, 80], 'pancreatitis'))
parkinsons_disease = TensorMap('parkinsons_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_parkinsons_disease':0, 'parkinsons_disease':1}, loss=weighted_crossentropy([1.0, 159], 'parkinsons_disease'))
peripheral_vascular_disease = TensorMap('peripheral_vascular_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_peripheral_vascular_disease':0, 'peripheral_vascular_disease':1}, loss=weighted_crossentropy([1.0, 41], 'peripheral_vascular_disease'))
pneumonia = TensorMap('pneumonia', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pneumonia':0, 'pneumonia':1}, loss=weighted_crossentropy([1.0, 13], 'pneumonia'))
posttraumatic_stress_disorder = TensorMap('posttraumatic_stress_disorder', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_posttraumatic_stress_disorder':0, 'posttraumatic_stress_disorder':1}, loss=weighted_crossentropy([1.0, 508], 'posttraumatic_stress_disorder'))
prostate_cancer = TensorMap('prostate_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_prostate_cancer':0, 'prostate_cancer':1}, loss=weighted_crossentropy([1.0, 32], 'prostate_cancer'))
psoriasis = TensorMap('psoriasis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_psoriasis':0, 'psoriasis':1}, loss=weighted_crossentropy([1.0, 34], 'psoriasis'))
pulmonary_hypertension = TensorMap('pulmonary_hypertension', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pulmonary_hypertension':0, 'pulmonary_hypertension':1}, loss=weighted_crossentropy([1.0, 273], 'pulmonary_hypertension'))
pulmonary_regurgitation = TensorMap('pulmonary_regurgitation', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pulmonary_regurgitation':0, 'pulmonary_regurgitation':1}, loss=weighted_crossentropy([1.0, 2234], 'pulmonary_regurgitation'))
pulmonary_stenosis = TensorMap('pulmonary_stenosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pulmonary_stenosis':0, 'pulmonary_stenosis':1}, loss=weighted_crossentropy([1.0, 14813], 'pulmonary_stenosis'))
pulmonary_valve_disease = TensorMap('pulmonary_valve_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_pulmonary_valve_disease':0, 'pulmonary_valve_disease':1}, loss=weighted_crossentropy([1.0, 1746], 'pulmonary_valve_disease'))
rheumatoid_arthritis = TensorMap('rheumatoid_arthritis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_rheumatoid_arthritis':0, 'rheumatoid_arthritis':1}, loss=weighted_crossentropy([1.0, 29], 'rheumatoid_arthritis'))
sarcoidosis = TensorMap('sarcoidosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_sarcoidosis':0, 'sarcoidosis':1}, loss=weighted_crossentropy([1.0, 182], 'sarcoidosis'))
schizophrenia = TensorMap('schizophrenia', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_schizophrenia':0, 'schizophrenia':1}, loss=weighted_crossentropy([1.0, 236], 'schizophrenia'))
sciatica = TensorMap('sciatica', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_sciatica':0, 'sciatica':1}, loss=weighted_crossentropy([1.0, 32], 'sciatica'))
skin_cancer = TensorMap('skin_cancer', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_skin_cancer':0, 'skin_cancer':1}, loss=weighted_crossentropy([1.0, 11], 'skin_cancer'))
sleep_apnea = TensorMap('sleep_apnea', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_sleep_apnea':0, 'sleep_apnea':1}, loss=weighted_crossentropy([1.0, 39], 'sleep_apnea'))
stroke = TensorMap('stroke', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_stroke':0, 'stroke':1}, loss=weighted_crossentropy([1.0, 21], 'stroke'))
subarachnoid_hemorrhage = TensorMap('subarachnoid_hemorrhage', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_subarachnoid_hemorrhage':0, 'subarachnoid_hemorrhage':1}, loss=weighted_crossentropy([1.0, 186], 'subarachnoid_hemorrhage'))
supraventricular_arrhythmia_general_inclusive_definition = TensorMap('supraventricular_arrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_general_inclusive_definition':0, 'supraventricular_arrhythmia_general_inclusive_definition':1}, loss=weighted_crossentropy([1.0, 68], 'supraventricular_arrhythmia_general_inclusive_definition'))
supraventricular_arrhythmia_general_inclusive_definition_clinical = TensorMap('supraventricular_arrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_general_inclusive_definition_clinical':0, 'supraventricular_arrhythmia_general_inclusive_definition_clinical':1}, loss=weighted_crossentropy([1.0, 66], 'supraventricular_arrhythmia_general_inclusive_definition_clinical'))
supraventricular_arrhythmia_premature_atrial_contractions = TensorMap('supraventricular_arrhythmia_premature_atrial_contractions', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_premature_atrial_contractions':0, 'supraventricular_arrhythmia_premature_atrial_contractions':1}, loss=weighted_crossentropy([1.0, 1659], 'supraventricular_arrhythmia_premature_atrial_contractions'))
supraventricular_arrhythmia_svt = TensorMap('supraventricular_arrhythmia_svt', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_svt':0, 'supraventricular_arrhythmia_svt':1}, loss=weighted_crossentropy([1.0, 69], 'supraventricular_arrhythmia_svt'))
supraventricular_arrhythmia_wpw = TensorMap('supraventricular_arrhythmia_wpw', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_wpw':0, 'supraventricular_arrhythmia_wpw':1}, loss=weighted_crossentropy([1.0, 603], 'supraventricular_arrhythmia_wpw'))
supraventricular_arrhythmia_wpw_v2 = TensorMap('supraventricular_arrhythmia_wpw_v2', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_supraventricular_arrhythmia_wpw_v2':0, 'supraventricular_arrhythmia_wpw_v2':1}, loss=weighted_crossentropy([1.0, 612], 'supraventricular_arrhythmia_wpw_v2'))
tricuspid_regurgitation = TensorMap('tricuspid_regurgitation', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_tricuspid_regurgitation':0, 'tricuspid_regurgitation':1}, loss=weighted_crossentropy([1.0, 493], 'tricuspid_regurgitation'))
tricuspid_stenosis = TensorMap('tricuspid_stenosis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_tricuspid_stenosis':0, 'tricuspid_stenosis':1}, loss=weighted_crossentropy([1.0, 26664], 'tricuspid_stenosis'))
tricuspid_valve_disease = TensorMap('tricuspid_valve_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_tricuspid_valve_disease':0, 'tricuspid_valve_disease':1}, loss=weighted_crossentropy([1.0, 139], 'tricuspid_valve_disease'))
ulcerative_colitis = TensorMap('ulcerative_colitis', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ulcerative_colitis':0, 'ulcerative_colitis':1}, loss=weighted_crossentropy([1.0, 53], 'ulcerative_colitis'))
uterine_fibroids = TensorMap('uterine_fibroids', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_uterine_fibroids':0, 'uterine_fibroids':1}, loss=weighted_crossentropy([1.0, 11], 'uterine_fibroids'))
valve_disease = TensorMap('valve_disease', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_valve_disease':0, 'valve_disease':1}, loss=weighted_crossentropy([1.0, 30], 'valve_disease'))
valvular_disease_unspecified = TensorMap('valvular_disease_unspecified', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_valvular_disease_unspecified':0, 'valvular_disease_unspecified':1}, loss=weighted_crossentropy([1.0, 65], 'valvular_disease_unspecified'))
venous_thromboembolism = TensorMap('venous_thromboembolism', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_venous_thromboembolism':0, 'venous_thromboembolism':1}, loss=weighted_crossentropy([1.0, 15], 'venous_thromboembolism'))
ventricular_arrhythmia_general_inclusive_definition = TensorMap('ventricular_arrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ventricular_arrhythmia_general_inclusive_definition':0, 'ventricular_arrhythmia_general_inclusive_definition':1}, loss=weighted_crossentropy([1.0, 80], 'ventricular_arrhythmia_general_inclusive_definition'))
ventricular_arrhythmia_general_inclusive_definition_clinical = TensorMap('ventricular_arrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ventricular_arrhythmia_general_inclusive_definition_clinical':0, 'ventricular_arrhythmia_general_inclusive_definition_clinical':1}, loss=weighted_crossentropy([1.0, 93], 'ventricular_arrhythmia_general_inclusive_definition_clinical'))
ventricular_arrhythmia_sudden_cardiac_death = TensorMap('ventricular_arrhythmia_sudden_cardiac_death', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ventricular_arrhythmia_sudden_cardiac_death':0, 'ventricular_arrhythmia_sudden_cardiac_death':1}, loss=weighted_crossentropy([1.0, 169], 'ventricular_arrhythmia_sudden_cardiac_death'))
ventricular_arrhythmia_ventricular_premature_depolarizations = TensorMap('ventricular_arrhythmia_ventricular_premature_depolarizations', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ventricular_arrhythmia_ventricular_premature_depolarizations':0, 'ventricular_arrhythmia_ventricular_premature_depolarizations':1}, loss=weighted_crossentropy([1.0, 484], 'ventricular_arrhythmia_ventricular_premature_depolarizations'))
ventricular_arrhythmia_vt = TensorMap('ventricular_arrhythmia_vt', Interpretation.CATEGORICAL, storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', channel_map={'no_ventricular_arrhythmia_vt':0, 'ventricular_arrhythmia_vt':1}, loss=weighted_crossentropy([1.0, 169], 'ventricular_arrhythmia_vt'))


#  TensorMaps for prevalent and incident MPG disease phenotypes
allergic_rhinitis_prevalent_incident = TensorMap('allergic_rhinitis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/allergic_rhinitis_date'), channel_map={'no_allergic_rhinitis':0, 'prevalent_allergic_rhinitis':1, 'incident_allergic_rhinitis':2}, loss=weighted_crossentropy([1.0, 5, 69], 'allergic_rhinitis_prevalent_incident'))
alzheimers_or_dementia_prevalent_incident = TensorMap('alzheimers_or_dementia', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/alzheimers_or_dementia_date'), channel_map={'no_alzheimers_or_dementia':0, 'prevalent_alzheimers_or_dementia':1, 'incident_alzheimers_or_dementia':2}, loss=weighted_crossentropy([1.0, 1339, 691], 'alzheimers_or_dementia_prevalent_incident'))
amyotrophic_lateral_sclerosis_prevalent_incident = TensorMap('amyotrophic_lateral_sclerosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/amyotrophic_lateral_sclerosis_date'), channel_map={'no_amyotrophic_lateral_sclerosis':0, 'prevalent_amyotrophic_lateral_sclerosis':1, 'incident_amyotrophic_lateral_sclerosis':2}, loss=weighted_crossentropy([1.0, 4053, 663], 'amyotrophic_lateral_sclerosis_prevalent_incident'))
anxiety_prevalent_incident = TensorMap('anxiety', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/anxiety_date'), channel_map={'no_anxiety':0, 'prevalent_anxiety':1, 'incident_anxiety':2}, loss=weighted_crossentropy([1.0, 56, 29], 'anxiety_prevalent_incident'))
aortic_regurgitation_prevalent_incident = TensorMap('aortic_regurgitation', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/aortic_regurgitation_date'), channel_map={'no_aortic_regurgitation':0, 'prevalent_aortic_regurgitation':1, 'incident_aortic_regurgitation':2}, loss=weighted_crossentropy([1.0, 291, 199], 'aortic_regurgitation_prevalent_incident'))
aortic_stenosis_prevalent_incident = TensorMap('aortic_stenosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/aortic_stenosis_date'), channel_map={'no_aortic_stenosis':0, 'prevalent_aortic_stenosis':1, 'incident_aortic_stenosis':2}, loss=weighted_crossentropy([1.0, 200, 106], 'aortic_stenosis_prevalent_incident'))
aortic_valve_disease_prevalent_incident = TensorMap('aortic_valve_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/aortic_valve_disease_date'), channel_map={'no_aortic_valve_disease':0, 'prevalent_aortic_valve_disease':1, 'incident_aortic_valve_disease':2}, loss=weighted_crossentropy([1.0, 93, 63], 'aortic_valve_disease_prevalent_incident'))
asthma_prevalent_incident = TensorMap('asthma', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/asthma_date'), channel_map={'no_asthma':0, 'prevalent_asthma':1, 'incident_asthma':2}, loss=weighted_crossentropy([1.0, 2, 32], 'asthma_prevalent_incident'))
atrial_fibrillation_or_flutter_prevalent_incident = TensorMap('atrial_fibrillation_or_flutter', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/atrial_fibrillation_or_flutter_date'), channel_map={'no_atrial_fibrillation_or_flutter':0, 'prevalent_atrial_fibrillation_or_flutter':1, 'incident_atrial_fibrillation_or_flutter':2}, loss=weighted_crossentropy([1.0, 21, 15], 'atrial_fibrillation_or_flutter_prevalent_incident'))
atrial_septal_defect_patent_foramen_ovale_prevalent_incident = TensorMap('atrial_septal_defect_patent_foramen_ovale', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/atrial_septal_defect_patent_foramen_ovale_date'), channel_map={'no_atrial_septal_defect_patent_foramen_ovale':0, 'prevalent_atrial_septal_defect_patent_foramen_ovale':1, 'incident_atrial_septal_defect_patent_foramen_ovale':2}, loss=weighted_crossentropy([1.0, 518, 524], 'atrial_septal_defect_patent_foramen_ovale_prevalent_incident'))
atrial_septal_defect_patent_foramen_ovale_v2_prevalent_incident = TensorMap('atrial_septal_defect_patent_foramen_ovale_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/atrial_septal_defect_patent_foramen_ovale_v2_date'), channel_map={'no_atrial_septal_defect_patent_foramen_ovale_v2':0, 'prevalent_atrial_septal_defect_patent_foramen_ovale_v2':1, 'incident_atrial_septal_defect_patent_foramen_ovale_v2':2}, loss=weighted_crossentropy([1.0, 518, 524], 'atrial_septal_defect_patent_foramen_ovale_v2_prevalent_incident'))
back_pain_prevalent_incident = TensorMap('back_pain', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/back_pain_date'), channel_map={'no_back_pain':0, 'prevalent_back_pain':1, 'incident_back_pain':2}, loss=weighted_crossentropy([1.0, 13, 17], 'back_pain_prevalent_incident'))
bariatric_surgery_prevalent_incident = TensorMap('bariatric_surgery', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bariatric_surgery_date'), channel_map={'no_bariatric_surgery':0, 'prevalent_bariatric_surgery':1, 'incident_bariatric_surgery':2}, loss=weighted_crossentropy([1.0, 630, 317], 'bariatric_surgery_prevalent_incident'))
bariatric_surgery_v2_prevalent_incident = TensorMap('bariatric_surgery_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bariatric_surgery_v2_date'), channel_map={'no_bariatric_surgery_v2':0, 'prevalent_bariatric_surgery_v2':1, 'incident_bariatric_surgery_v2':2}, loss=weighted_crossentropy([1.0, 1239, 441], 'bariatric_surgery_v2_prevalent_incident'))
bipolar_disorder_prevalent_incident = TensorMap('bipolar_disorder', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bipolar_disorder_date'), channel_map={'no_bipolar_disorder':0, 'prevalent_bipolar_disorder':1, 'incident_bipolar_disorder':2}, loss=weighted_crossentropy([1.0, 106, 445], 'bipolar_disorder_prevalent_incident'))
bladder_cancer_prevalent_incident = TensorMap('bladder_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bladder_cancer_date'), channel_map={'no_bladder_cancer':0, 'prevalent_bladder_cancer':1, 'incident_bladder_cancer':2}, loss=weighted_crossentropy([1.0, 122, 121], 'bladder_cancer_prevalent_incident'))
bradyarrhythmia_av_block_or_distal_conduction_disease_prevalent_incident = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_av_block_or_distal_conduction_disease_date'), channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease':0, 'prevalent_bradyarrhythmia_av_block_or_distal_conduction_disease':1, 'incident_bradyarrhythmia_av_block_or_distal_conduction_disease':2}, loss=weighted_crossentropy([1.0, 92, 39], 'bradyarrhythmia_av_block_or_distal_conduction_disease_prevalent_incident'))
bradyarrhythmia_av_block_or_distal_conduction_disease_hard_prevalent_incident = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_hard', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_av_block_or_distal_conduction_disease_hard_date'), channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_hard':0, 'prevalent_bradyarrhythmia_av_block_or_distal_conduction_disease_hard':1, 'incident_bradyarrhythmia_av_block_or_distal_conduction_disease_hard':2}, loss=weighted_crossentropy([1.0, 171, 66], 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard_prevalent_incident'))
bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2_prevalent_incident = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2_date'), channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2':0, 'prevalent_bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2':1, 'incident_bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2':2}, loss=weighted_crossentropy([1.0, 180, 67], 'bradyarrhythmia_av_block_or_distal_conduction_disease_hard_v2_prevalent_incident'))
bradyarrhythmia_av_block_or_distal_conduction_disease_v2_prevalent_incident = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_av_block_or_distal_conduction_disease_v2_date'), channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_v2':0, 'prevalent_bradyarrhythmia_av_block_or_distal_conduction_disease_v2':1, 'incident_bradyarrhythmia_av_block_or_distal_conduction_disease_v2':2}, loss=weighted_crossentropy([1.0, 135, 59], 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2_prevalent_incident'))
bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted_prevalent_incident = TensorMap('bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted_date'), channel_map={'no_bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted':0, 'prevalent_bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted':1, 'incident_bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted':2}, loss=weighted_crossentropy([1.0, 488, 280], 'bradyarrhythmia_av_block_or_distal_conduction_disease_v2_restricted_prevalent_incident'))
bradyarrhythmia_general_inclusive_definition_prevalent_incident = TensorMap('bradyarrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_general_inclusive_definition_date'), channel_map={'no_bradyarrhythmia_general_inclusive_definition':0, 'prevalent_bradyarrhythmia_general_inclusive_definition':1, 'incident_bradyarrhythmia_general_inclusive_definition':2}, loss=weighted_crossentropy([1.0, 52, 27], 'bradyarrhythmia_general_inclusive_definition_prevalent_incident'))
bradyarrhythmia_only_prevalent_incident = TensorMap('bradyarrhythmia_only', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_only_date'), channel_map={'no_bradyarrhythmia_only':0, 'prevalent_bradyarrhythmia_only':1, 'incident_bradyarrhythmia_only':2}, loss=weighted_crossentropy([1.0, 83, 54], 'bradyarrhythmia_only_prevalent_incident'))
bradyarrhythmia_pacemaker_prevalent_incident = TensorMap('bradyarrhythmia_pacemaker', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_pacemaker_date'), channel_map={'no_bradyarrhythmia_pacemaker':0, 'prevalent_bradyarrhythmia_pacemaker':1, 'incident_bradyarrhythmia_pacemaker':2}, loss=weighted_crossentropy([1.0, 91, 58], 'bradyarrhythmia_pacemaker_prevalent_incident'))
bradyarrhythmia_pacemaker_v2_prevalent_incident = TensorMap('bradyarrhythmia_pacemaker_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_pacemaker_v2_date'), channel_map={'no_bradyarrhythmia_pacemaker_v2':0, 'prevalent_bradyarrhythmia_pacemaker_v2':1, 'incident_bradyarrhythmia_pacemaker_v2':2}, loss=weighted_crossentropy([1.0, 90, 56], 'bradyarrhythmia_pacemaker_v2_prevalent_incident'))
bradyarrhythmia_sinus_node_dysfunction_prevalent_incident = TensorMap('bradyarrhythmia_sinus_node_dysfunction', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_sinus_node_dysfunction_date'), channel_map={'no_bradyarrhythmia_sinus_node_dysfunction':0, 'prevalent_bradyarrhythmia_sinus_node_dysfunction':1, 'incident_bradyarrhythmia_sinus_node_dysfunction':2}, loss=weighted_crossentropy([1.0, 937, 535], 'bradyarrhythmia_sinus_node_dysfunction_prevalent_incident'))
bradyarrhythmia_sinus_node_dysfunction_hard_prevalent_incident = TensorMap('bradyarrhythmia_sinus_node_dysfunction_hard', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_sinus_node_dysfunction_hard_date'), channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_hard':0, 'prevalent_bradyarrhythmia_sinus_node_dysfunction_hard':1, 'incident_bradyarrhythmia_sinus_node_dysfunction_hard':2}, loss=weighted_crossentropy([1.0, 1304, 802], 'bradyarrhythmia_sinus_node_dysfunction_hard_prevalent_incident'))
bradyarrhythmia_sinus_node_dysfunction_hard_v2_prevalent_incident = TensorMap('bradyarrhythmia_sinus_node_dysfunction_hard_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_sinus_node_dysfunction_hard_v2_date'), channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_hard_v2':0, 'prevalent_bradyarrhythmia_sinus_node_dysfunction_hard_v2':1, 'incident_bradyarrhythmia_sinus_node_dysfunction_hard_v2':2}, loss=weighted_crossentropy([1.0, 1339, 842], 'bradyarrhythmia_sinus_node_dysfunction_hard_v2_prevalent_incident'))
bradyarrhythmia_sinus_node_dysfunction_v2_prevalent_incident = TensorMap('bradyarrhythmia_sinus_node_dysfunction_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_sinus_node_dysfunction_v2_date'), channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_v2':0, 'prevalent_bradyarrhythmia_sinus_node_dysfunction_v2':1, 'incident_bradyarrhythmia_sinus_node_dysfunction_v2':2}, loss=weighted_crossentropy([1.0, 1079, 731], 'bradyarrhythmia_sinus_node_dysfunction_v2_prevalent_incident'))
bradyarrhythmia_sinus_node_dysfunction_v2_restricted_prevalent_incident = TensorMap('bradyarrhythmia_sinus_node_dysfunction_v2_restricted', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrhythmia_sinus_node_dysfunction_v2_restricted_date'), channel_map={'no_bradyarrhythmia_sinus_node_dysfunction_v2_restricted':0, 'prevalent_bradyarrhythmia_sinus_node_dysfunction_v2_restricted':1, 'incident_bradyarrhythmia_sinus_node_dysfunction_v2_restricted':2}, loss=weighted_crossentropy([1.0, 1304, 973], 'bradyarrhythmia_sinus_node_dysfunction_v2_restricted_prevalent_incident'))
bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical_prevalent_incident = TensorMap('bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical_date'), channel_map={'no_bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical':0, 'prevalent_bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical':1, 'incident_bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical':2}, loss=weighted_crossentropy([1.0, 84, 54], 'bradyarrrhythmia_av_block_or_distal_conduction_disease_clinical_prevalent_incident'))
bradyarrrhythmia_general_inclusive_definition_clinical_prevalent_incident = TensorMap('bradyarrrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/bradyarrrhythmia_general_inclusive_definition_clinical_date'), channel_map={'no_bradyarrrhythmia_general_inclusive_definition_clinical':0, 'prevalent_bradyarrrhythmia_general_inclusive_definition_clinical':1, 'incident_bradyarrrhythmia_general_inclusive_definition_clinical':2}, loss=weighted_crossentropy([1.0, 82, 52], 'bradyarrrhythmia_general_inclusive_definition_clinical_prevalent_incident'))
breast_cancer_prevalent_incident = TensorMap('breast_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/breast_cancer_date'), channel_map={'no_breast_cancer':0, 'prevalent_breast_cancer':1, 'incident_breast_cancer':2}, loss=weighted_crossentropy([1.0, 14, 32], 'breast_cancer_prevalent_incident'))
cardiac_surgery_prevalent_incident = TensorMap('cardiac_surgery', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/cardiac_surgery_date'), channel_map={'no_cardiac_surgery':0, 'prevalent_cardiac_surgery':1, 'incident_cardiac_surgery':2}, loss=weighted_crossentropy([1.0, 39, 49], 'cardiac_surgery_prevalent_incident'))
cataract_prevalent_incident = TensorMap('cataract', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/cataract_date'), channel_map={'no_cataract':0, 'prevalent_cataract':1, 'incident_cataract':2}, loss=weighted_crossentropy([1.0, 11, 10], 'cataract_prevalent_incident'))
cervical_cancer_prevalent_incident = TensorMap('cervical_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/cervical_cancer_date'), channel_map={'no_cervical_cancer':0, 'prevalent_cervical_cancer':1, 'incident_cervical_cancer':2}, loss=weighted_crossentropy([1.0, 78, 1414], 'cervical_cancer_prevalent_incident'))
cholelithiasis_or_gallstones_prevalent_incident = TensorMap('cholelithiasis_or_gallstones', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/cholelithiasis_or_gallstones_date'), channel_map={'no_cholelithiasis_or_gallstones':0, 'prevalent_cholelithiasis_or_gallstones':1, 'incident_cholelithiasis_or_gallstones':2}, loss=weighted_crossentropy([1.0, 11, 22], 'cholelithiasis_or_gallstones_prevalent_incident'))
chronic_kidney_disease_prevalent_incident = TensorMap('chronic_kidney_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/chronic_kidney_disease_date'), channel_map={'no_chronic_kidney_disease':0, 'prevalent_chronic_kidney_disease':1, 'incident_chronic_kidney_disease':2}, loss=weighted_crossentropy([1.0, 104, 31], 'chronic_kidney_disease_prevalent_incident'))
chronic_obstructive_pulmonary_disease_prevalent_incident = TensorMap('chronic_obstructive_pulmonary_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/chronic_obstructive_pulmonary_disease_date'), channel_map={'no_chronic_obstructive_pulmonary_disease':0, 'prevalent_chronic_obstructive_pulmonary_disease':1, 'incident_chronic_obstructive_pulmonary_disease':2}, loss=weighted_crossentropy([1.0, 15, 27], 'chronic_obstructive_pulmonary_disease_prevalent_incident'))
colorectal_cancer_prevalent_incident = TensorMap('colorectal_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/colorectal_cancer_date'), channel_map={'no_colorectal_cancer':0, 'prevalent_colorectal_cancer':1, 'incident_colorectal_cancer':2}, loss=weighted_crossentropy([1.0, 59, 71], 'colorectal_cancer_prevalent_incident'))
conduction_system_disease_only_prevalent_incident = TensorMap('conduction_system_disease_only', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/conduction_system_disease_only_date'), channel_map={'no_conduction_system_disease_only':0, 'prevalent_conduction_system_disease_only':1, 'incident_conduction_system_disease_only':2}, loss=weighted_crossentropy([1.0, 118, 46], 'conduction_system_disease_only_prevalent_incident'))
congenital_heart_disease_prevalent_incident = TensorMap('congenital_heart_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/congenital_heart_disease_date'), channel_map={'no_congenital_heart_disease':0, 'prevalent_congenital_heart_disease':1, 'incident_congenital_heart_disease':2}, loss=weighted_crossentropy([1.0, 298, 262], 'congenital_heart_disease_prevalent_incident'))
congenital_heart_disease_ebstein_anomaly_prevalent_incident = TensorMap('congenital_heart_disease_ebstein_anomaly', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/congenital_heart_disease_ebstein_anomaly_date'), channel_map={'no_congenital_heart_disease_ebstein_anomaly':0, 'prevalent_congenital_heart_disease_ebstein_anomaly':1, 'incident_congenital_heart_disease_ebstein_anomaly':2}, loss=weighted_crossentropy([1.0, 21427, 149989], 'congenital_heart_disease_ebstein_anomaly_prevalent_incident'))
coronary_artery_disease_prevalent_incident = TensorMap('coronary_artery_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/coronary_artery_disease_date'), channel_map={'no_coronary_artery_disease':0, 'prevalent_coronary_artery_disease':1, 'incident_coronary_artery_disease':2}, loss=weighted_crossentropy([1.0, 10, 19], 'coronary_artery_disease_prevalent_incident'))
coronary_artery_disease_hard_prevalent_incident = TensorMap('coronary_artery_disease_hard', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/coronary_artery_disease_hard_date'), channel_map={'no_coronary_artery_disease_hard':0, 'prevalent_coronary_artery_disease_hard':1, 'incident_coronary_artery_disease_hard':2}, loss=weighted_crossentropy([1.0, 9, 18], 'coronary_artery_disease_hard_prevalent_incident'))
coronary_artery_disease_intermediate_prevalent_incident = TensorMap('coronary_artery_disease_intermediate', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/coronary_artery_disease_intermediate_date'), channel_map={'no_coronary_artery_disease_intermediate':0, 'prevalent_coronary_artery_disease_intermediate':1, 'incident_coronary_artery_disease_intermediate':2}, loss=weighted_crossentropy([1.0, 8, 11], 'coronary_artery_disease_intermediate_prevalent_incident'))
coronary_artery_disease_soft_prevalent_incident = TensorMap('coronary_artery_disease_soft', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/coronary_artery_disease_soft_date'), channel_map={'no_coronary_artery_disease_soft':0, 'prevalent_coronary_artery_disease_soft':1, 'incident_coronary_artery_disease_soft':2}, loss=weighted_crossentropy([1.0, 5, 10], 'coronary_artery_disease_soft_prevalent_incident'))
crohns_disease_prevalent_incident = TensorMap('crohns_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/crohns_disease_date'), channel_map={'no_crohns_disease':0, 'prevalent_crohns_disease':1, 'incident_crohns_disease':2}, loss=weighted_crossentropy([1.0, 114, 245], 'crohns_disease_prevalent_incident'))
death_prevalent_incident = TensorMap('death', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/death_date'), channel_map={'no_death':0, 'prevalent_death':1, 'incident_death':2}, loss=weighted_crossentropy([1.0, 37497, 11], 'death_prevalent_incident'))
depression_prevalent_incident = TensorMap('depression', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/depression_date'), channel_map={'no_depression':0, 'prevalent_depression':1, 'incident_depression':2}, loss=weighted_crossentropy([1.0, 5, 22], 'depression_prevalent_incident'))
dermatitis_prevalent_incident = TensorMap('dermatitis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/dermatitis_date'), channel_map={'no_dermatitis':0, 'prevalent_dermatitis':1, 'incident_dermatitis':2}, loss=weighted_crossentropy([1.0, 12, 56], 'dermatitis_prevalent_incident'))
diabetes_all_prevalent_incident = TensorMap('diabetes_all', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/diabetes_all_date'), channel_map={'no_diabetes_all':0, 'prevalent_diabetes_all':1, 'incident_diabetes_all':2}, loss=weighted_crossentropy([1.0, 6, 23], 'diabetes_all_prevalent_incident'))
diabetes_type_1_prevalent_incident = TensorMap('diabetes_type_1', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/diabetes_type_1_date'), channel_map={'no_diabetes_type_1':0, 'prevalent_diabetes_type_1':1, 'incident_diabetes_type_1':2}, loss=weighted_crossentropy([1.0, 62, 121], 'diabetes_type_1_prevalent_incident'))
diabetes_type_2_prevalent_incident = TensorMap('diabetes_type_2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/diabetes_type_2_date'), channel_map={'no_diabetes_type_2':0, 'prevalent_diabetes_type_2':1, 'incident_diabetes_type_2':2}, loss=weighted_crossentropy([1.0, 14, 12], 'diabetes_type_2_prevalent_incident'))
diverticular_disease_prevalent_incident = TensorMap('diverticular_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/diverticular_disease_date'), channel_map={'no_diverticular_disease':0, 'prevalent_diverticular_disease':1, 'incident_diverticular_disease':2}, loss=weighted_crossentropy([1.0, 11, 8], 'diverticular_disease_prevalent_incident'))
enlarged_prostate_prevalent_incident = TensorMap('enlarged_prostate', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/enlarged_prostate_date'), channel_map={'no_enlarged_prostate':0, 'prevalent_enlarged_prostate':1, 'incident_enlarged_prostate':2}, loss=weighted_crossentropy([1.0, 16, 22], 'enlarged_prostate_prevalent_incident'))
epilepsy_prevalent_incident = TensorMap('epilepsy', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/epilepsy_date'), channel_map={'no_epilepsy':0, 'prevalent_epilepsy':1, 'incident_epilepsy':2}, loss=weighted_crossentropy([1.0, 34, 132], 'epilepsy_prevalent_incident'))
gastroesophageal_reflux_disease_prevalent_incident = TensorMap('gastroesophageal_reflux_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/gastroesophageal_reflux_disease_date'), channel_map={'no_gastroesophageal_reflux_disease':0, 'prevalent_gastroesophageal_reflux_disease':1, 'incident_gastroesophageal_reflux_disease':2}, loss=weighted_crossentropy([1.0, 5, 11], 'gastroesophageal_reflux_disease_prevalent_incident'))
glaucoma_prevalent_incident = TensorMap('glaucoma', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/glaucoma_date'), channel_map={'no_glaucoma':0, 'prevalent_glaucoma':1, 'incident_glaucoma':2}, loss=weighted_crossentropy([1.0, 28, 59], 'glaucoma_prevalent_incident'))
gout_prevalent_incident = TensorMap('gout', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/gout_date'), channel_map={'no_gout':0, 'prevalent_gout':1, 'incident_gout':2}, loss=weighted_crossentropy([1.0, 22, 97], 'gout_prevalent_incident'))
heart_failure_prevalent_incident = TensorMap('heart_failure', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/heart_failure_date'), channel_map={'no_heart_failure':0, 'prevalent_heart_failure':1, 'incident_heart_failure':2}, loss=weighted_crossentropy([1.0, 58, 33], 'heart_failure_prevalent_incident'))
heart_failure_v2_prevalent_incident = TensorMap('heart_failure_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/heart_failure_v2_date'), channel_map={'no_heart_failure_v2':0, 'prevalent_heart_failure_v2':1, 'incident_heart_failure_v2':2}, loss=weighted_crossentropy([1.0, 58, 33], 'heart_failure_v2_prevalent_incident'))
hypercholesterolemia_prevalent_incident = TensorMap('hypercholesterolemia', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/hypercholesterolemia_date'), channel_map={'no_hypercholesterolemia':0, 'prevalent_hypercholesterolemia':1, 'incident_hypercholesterolemia':2}, loss=weighted_crossentropy([1.0, 2, 9], 'hypercholesterolemia_prevalent_incident'))
hypertension_prevalent_incident = TensorMap('hypertension', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/hypertension_date'), channel_map={'no_hypertension':0, 'prevalent_hypertension':1, 'incident_hypertension':2}, loss=weighted_crossentropy([1.0, 1, 7], 'hypertension_prevalent_incident'))
hyperthyroidism_prevalent_incident = TensorMap('hyperthyroidism', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/hyperthyroidism_date'), channel_map={'no_hyperthyroidism':0, 'prevalent_hyperthyroidism':1, 'incident_hyperthyroidism':2}, loss=weighted_crossentropy([1.0, 38, 149], 'hyperthyroidism_prevalent_incident'))
hypertrophic_cardiomyopathy_prevalent_incident = TensorMap('hypertrophic_cardiomyopathy', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/hypertrophic_cardiomyopathy_date'), channel_map={'no_hypertrophic_cardiomyopathy':0, 'prevalent_hypertrophic_cardiomyopathy':1, 'incident_hypertrophic_cardiomyopathy':2}, loss=weighted_crossentropy([1.0, 789, 1127], 'hypertrophic_cardiomyopathy_prevalent_incident'))
hypothyroidism_prevalent_incident = TensorMap('hypothyroidism', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/hypothyroidism_date'), channel_map={'no_hypothyroidism':0, 'prevalent_hypothyroidism':1, 'incident_hypothyroidism':2}, loss=weighted_crossentropy([1.0, 6, 39], 'hypothyroidism_prevalent_incident'))
implantable_cardioverter_defibrillator_prevalent_incident = TensorMap('implantable_cardioverter_defibrillator', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/implantable_cardioverter_defibrillator_date'), channel_map={'no_implantable_cardioverter_defibrillator':0, 'prevalent_implantable_cardioverter_defibrillator':1, 'incident_implantable_cardioverter_defibrillator':2}, loss=weighted_crossentropy([1.0, 1376, 261], 'implantable_cardioverter_defibrillator_prevalent_incident'))
inflammatory_bowel_disease_prevalent_incident = TensorMap('inflammatory_bowel_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/inflammatory_bowel_disease_date'), channel_map={'no_inflammatory_bowel_disease':0, 'prevalent_inflammatory_bowel_disease':1, 'incident_inflammatory_bowel_disease':2}, loss=weighted_crossentropy([1.0, 31, 130], 'inflammatory_bowel_disease_prevalent_incident'))
intervertebral_disc_displacement_prevalent_incident = TensorMap('intervertebral_disc_displacement', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/intervertebral_disc_displacement_date'), channel_map={'no_intervertebral_disc_displacement':0, 'prevalent_intervertebral_disc_displacement':1, 'incident_intervertebral_disc_displacement':2}, loss=weighted_crossentropy([1.0, 17, 81], 'intervertebral_disc_displacement_prevalent_incident'))
intracerebral_hemorrhage_prevalent_incident = TensorMap('intracerebral_hemorrhage', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/intracerebral_hemorrhage_date'), channel_map={'no_intracerebral_hemorrhage':0, 'prevalent_intracerebral_hemorrhage':1, 'incident_intracerebral_hemorrhage':2}, loss=weighted_crossentropy([1.0, 351, 265], 'intracerebral_hemorrhage_prevalent_incident'))
iron_deficiency_anemia_prevalent_incident = TensorMap('iron_deficiency_anemia', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/iron_deficiency_anemia_date'), channel_map={'no_iron_deficiency_anemia':0, 'prevalent_iron_deficiency_anemia':1, 'incident_iron_deficiency_anemia':2}, loss=weighted_crossentropy([1.0, 26, 25], 'iron_deficiency_anemia_prevalent_incident'))
irritable_bowel_syndrome_prevalent_incident = TensorMap('irritable_bowel_syndrome', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/irritable_bowel_syndrome_date'), channel_map={'no_irritable_bowel_syndrome':0, 'prevalent_irritable_bowel_syndrome':1, 'incident_irritable_bowel_syndrome':2}, loss=weighted_crossentropy([1.0, 12, 55], 'irritable_bowel_syndrome_prevalent_incident'))
ischemic_stroke_prevalent_incident = TensorMap('ischemic_stroke', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ischemic_stroke_date'), channel_map={'no_ischemic_stroke':0, 'prevalent_ischemic_stroke':1, 'incident_ischemic_stroke':2}, loss=weighted_crossentropy([1.0, 87, 54], 'ischemic_stroke_prevalent_incident'))
lung_cancer_prevalent_incident = TensorMap('lung_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/lung_cancer_date'), channel_map={'no_lung_cancer':0, 'prevalent_lung_cancer':1, 'incident_lung_cancer':2}, loss=weighted_crossentropy([1.0, 313, 68], 'lung_cancer_prevalent_incident'))
lupus_erythematosus_prevalent_incident = TensorMap('lupus_erythematosus', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/lupus_erythematosus_date'), channel_map={'no_lupus_erythematosus':0, 'prevalent_lupus_erythematosus':1, 'incident_lupus_erythematosus':2}, loss=weighted_crossentropy([1.0, 235, 955], 'lupus_erythematosus_prevalent_incident'))
migraine_prevalent_incident = TensorMap('migraine', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/migraine_date'), channel_map={'no_migraine':0, 'prevalent_migraine':1, 'incident_migraine':2}, loss=weighted_crossentropy([1.0, 10, 77], 'migraine_prevalent_incident'))
mitral_regurgitation_prevalent_incident = TensorMap('mitral_regurgitation', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/mitral_regurgitation_date'), channel_map={'no_mitral_regurgitation':0, 'prevalent_mitral_regurgitation':1, 'incident_mitral_regurgitation':2}, loss=weighted_crossentropy([1.0, 184, 101], 'mitral_regurgitation_prevalent_incident'))
mitral_stenosis_prevalent_incident = TensorMap('mitral_stenosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/mitral_stenosis_date'), channel_map={'no_mitral_stenosis':0, 'prevalent_mitral_stenosis':1, 'incident_mitral_stenosis':2}, loss=weighted_crossentropy([1.0, 1764, 2884], 'mitral_stenosis_prevalent_incident'))
mitral_valve_disease_prevalent_incident = TensorMap('mitral_valve_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/mitral_valve_disease_date'), channel_map={'no_mitral_valve_disease':0, 'prevalent_mitral_valve_disease':1, 'incident_mitral_valve_disease':2}, loss=weighted_crossentropy([1.0, 104, 59], 'mitral_valve_disease_prevalent_incident'))
mitral_valve_prolapse_prevalent_incident = TensorMap('mitral_valve_prolapse', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/mitral_valve_prolapse_date'), channel_map={'no_mitral_valve_prolapse':0, 'prevalent_mitral_valve_prolapse':1, 'incident_mitral_valve_prolapse':2}, loss=weighted_crossentropy([1.0, 553, 513], 'mitral_valve_prolapse_prevalent_incident'))
multiple_sclerosis_prevalent_incident = TensorMap('multiple_sclerosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/multiple_sclerosis_date'), channel_map={'no_multiple_sclerosis':0, 'prevalent_multiple_sclerosis':1, 'incident_multiple_sclerosis':2}, loss=weighted_crossentropy([1.0, 82, 753], 'multiple_sclerosis_prevalent_incident'))
myocardial_infarction_prevalent_incident = TensorMap('myocardial_infarction', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/myocardial_infarction_date'), channel_map={'no_myocardial_infarction':0, 'prevalent_myocardial_infarction':1, 'incident_myocardial_infarction':2}, loss=weighted_crossentropy([1.0, 13, 27], 'myocardial_infarction_prevalent_incident'))
osteoarthritis_prevalent_incident = TensorMap('osteoarthritis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/osteoarthritis_date'), channel_map={'no_osteoarthritis':0, 'prevalent_osteoarthritis':1, 'incident_osteoarthritis':2}, loss=weighted_crossentropy([1.0, 3, 6], 'osteoarthritis_prevalent_incident'))
osteoporosis_prevalent_incident = TensorMap('osteoporosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/osteoporosis_date'), channel_map={'no_osteoporosis':0, 'prevalent_osteoporosis':1, 'incident_osteoporosis':2}, loss=weighted_crossentropy([1.0, 17, 41], 'osteoporosis_prevalent_incident'))
pancreatitis_prevalent_incident = TensorMap('pancreatitis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pancreatitis_date'), channel_map={'no_pancreatitis':0, 'prevalent_pancreatitis':1, 'incident_pancreatitis':2}, loss=weighted_crossentropy([1.0, 86, 131], 'pancreatitis_prevalent_incident'))
parkinsons_disease_prevalent_incident = TensorMap('parkinsons_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/parkinsons_disease_date'), channel_map={'no_parkinsons_disease':0, 'prevalent_parkinsons_disease':1, 'incident_parkinsons_disease':2}, loss=weighted_crossentropy([1.0, 180, 235], 'parkinsons_disease_prevalent_incident'))
peripheral_vascular_disease_prevalent_incident = TensorMap('peripheral_vascular_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/peripheral_vascular_disease_date'), channel_map={'no_peripheral_vascular_disease':0, 'prevalent_peripheral_vascular_disease':1, 'incident_peripheral_vascular_disease':2}, loss=weighted_crossentropy([1.0, 47, 71], 'peripheral_vascular_disease_prevalent_incident'))
pneumonia_prevalent_incident = TensorMap('pneumonia', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pneumonia_date'), channel_map={'no_pneumonia':0, 'prevalent_pneumonia':1, 'incident_pneumonia':2}, loss=weighted_crossentropy([1.0, 17, 18], 'pneumonia_prevalent_incident'))
posttraumatic_stress_disorder_prevalent_incident = TensorMap('posttraumatic_stress_disorder', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/posttraumatic_stress_disorder_date'), channel_map={'no_posttraumatic_stress_disorder':0, 'prevalent_posttraumatic_stress_disorder':1, 'incident_posttraumatic_stress_disorder':2}, loss=weighted_crossentropy([1.0, 461, 1704], 'posttraumatic_stress_disorder_prevalent_incident'))
prostate_cancer_prevalent_incident = TensorMap('prostate_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/prostate_cancer_date'), channel_map={'no_prostate_cancer':0, 'prevalent_prostate_cancer':1, 'incident_prostate_cancer':2}, loss=weighted_crossentropy([1.0, 45, 41], 'prostate_cancer_prevalent_incident'))
psoriasis_prevalent_incident = TensorMap('psoriasis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/psoriasis_date'), channel_map={'no_psoriasis':0, 'prevalent_psoriasis':1, 'incident_psoriasis':2}, loss=weighted_crossentropy([1.0, 26, 144], 'psoriasis_prevalent_incident'))
pulmonary_hypertension_prevalent_incident = TensorMap('pulmonary_hypertension', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pulmonary_hypertension_date'), channel_map={'no_pulmonary_hypertension':0, 'prevalent_pulmonary_hypertension':1, 'incident_pulmonary_hypertension':2}, loss=weighted_crossentropy([1.0, 993, 241], 'pulmonary_hypertension_prevalent_incident'))
pulmonary_regurgitation_prevalent_incident = TensorMap('pulmonary_regurgitation', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pulmonary_regurgitation_date'), channel_map={'no_pulmonary_regurgitation':0, 'prevalent_pulmonary_regurgitation':1, 'incident_pulmonary_regurgitation':2}, loss=weighted_crossentropy([1.0, 7894, 1973], 'pulmonary_regurgitation_prevalent_incident'))
pulmonary_stenosis_prevalent_incident = TensorMap('pulmonary_stenosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pulmonary_stenosis_date'), channel_map={'no_pulmonary_stenosis':0, 'prevalent_pulmonary_stenosis':1, 'incident_pulmonary_stenosis':2}, loss=weighted_crossentropy([1.0, 9374, 14998], 'pulmonary_stenosis_prevalent_incident'))
pulmonary_valve_disease_prevalent_incident = TensorMap('pulmonary_valve_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/pulmonary_valve_disease_date'), channel_map={'no_pulmonary_valve_disease':0, 'prevalent_pulmonary_valve_disease':1, 'incident_pulmonary_valve_disease':2}, loss=weighted_crossentropy([1.0, 3488, 1648], 'pulmonary_valve_disease_prevalent_incident'))
rheumatoid_arthritis_prevalent_incident = TensorMap('rheumatoid_arthritis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/rheumatoid_arthritis_date'), channel_map={'no_rheumatoid_arthritis':0, 'prevalent_rheumatoid_arthritis':1, 'incident_rheumatoid_arthritis':2}, loss=weighted_crossentropy([1.0, 25, 86], 'rheumatoid_arthritis_prevalent_incident'))
sarcoidosis_prevalent_incident = TensorMap('sarcoidosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/sarcoidosis_date'), channel_map={'no_sarcoidosis':0, 'prevalent_sarcoidosis':1, 'incident_sarcoidosis':2}, loss=weighted_crossentropy([1.0, 149, 789], 'sarcoidosis_prevalent_incident'))
schizophrenia_prevalent_incident = TensorMap('schizophrenia', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/schizophrenia_date'), channel_map={'no_schizophrenia':0, 'prevalent_schizophrenia':1, 'incident_schizophrenia':2}, loss=weighted_crossentropy([1.0, 189, 887], 'schizophrenia_prevalent_incident'))
sciatica_prevalent_incident = TensorMap('sciatica', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/sciatica_date'), channel_map={'no_sciatica':0, 'prevalent_sciatica':1, 'incident_sciatica':2}, loss=weighted_crossentropy([1.0, 27, 100], 'sciatica_prevalent_incident'))
skin_cancer_prevalent_incident = TensorMap('skin_cancer', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/skin_cancer_date'), channel_map={'no_skin_cancer':0, 'prevalent_skin_cancer':1, 'incident_skin_cancer':2}, loss=weighted_crossentropy([1.0, 13, 20], 'skin_cancer_prevalent_incident'))
sleep_apnea_prevalent_incident = TensorMap('sleep_apnea', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/sleep_apnea_date'), channel_map={'no_sleep_apnea':0, 'prevalent_sleep_apnea':1, 'incident_sleep_apnea':2}, loss=weighted_crossentropy([1.0, 49, 56], 'sleep_apnea_prevalent_incident'))
stroke_prevalent_incident = TensorMap('stroke', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/stroke_date'), channel_map={'no_stroke':0, 'prevalent_stroke':1, 'incident_stroke':2}, loss=weighted_crossentropy([1.0, 21, 42], 'stroke_prevalent_incident'))
subarachnoid_hemorrhage_prevalent_incident = TensorMap('subarachnoid_hemorrhage', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/subarachnoid_hemorrhage_date'), channel_map={'no_subarachnoid_hemorrhage':0, 'prevalent_subarachnoid_hemorrhage':1, 'incident_subarachnoid_hemorrhage':2}, loss=weighted_crossentropy([1.0, 175, 374], 'subarachnoid_hemorrhage_prevalent_incident'))
supraventricular_arrhythmia_general_inclusive_definition_prevalent_incident = TensorMap('supraventricular_arrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_general_inclusive_definition_date'), channel_map={'no_supraventricular_arrhythmia_general_inclusive_definition':0, 'prevalent_supraventricular_arrhythmia_general_inclusive_definition':1, 'incident_supraventricular_arrhythmia_general_inclusive_definition':2}, loss=weighted_crossentropy([1.0, 84, 104], 'supraventricular_arrhythmia_general_inclusive_definition_prevalent_incident'))
supraventricular_arrhythmia_general_inclusive_definition_clinical_prevalent_incident = TensorMap('supraventricular_arrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_general_inclusive_definition_clinical_date'), channel_map={'no_supraventricular_arrhythmia_general_inclusive_definition_clinical':0, 'prevalent_supraventricular_arrhythmia_general_inclusive_definition_clinical':1, 'incident_supraventricular_arrhythmia_general_inclusive_definition_clinical':2}, loss=weighted_crossentropy([1.0, 78, 107], 'supraventricular_arrhythmia_general_inclusive_definition_clinical_prevalent_incident'))
supraventricular_arrhythmia_premature_atrial_contractions_prevalent_incident = TensorMap('supraventricular_arrhythmia_premature_atrial_contractions', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_premature_atrial_contractions_date'), channel_map={'no_supraventricular_arrhythmia_premature_atrial_contractions':0, 'prevalent_supraventricular_arrhythmia_premature_atrial_contractions':1, 'incident_supraventricular_arrhythmia_premature_atrial_contractions':2}, loss=weighted_crossentropy([1.0, 2727, 1704], 'supraventricular_arrhythmia_premature_atrial_contractions_prevalent_incident'))
supraventricular_arrhythmia_svt_prevalent_incident = TensorMap('supraventricular_arrhythmia_svt', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_svt_date'), channel_map={'no_supraventricular_arrhythmia_svt':0, 'prevalent_supraventricular_arrhythmia_svt':1, 'incident_supraventricular_arrhythmia_svt':2}, loss=weighted_crossentropy([1.0, 83, 113], 'supraventricular_arrhythmia_svt_prevalent_incident'))
supraventricular_arrhythmia_wpw_prevalent_incident = TensorMap('supraventricular_arrhythmia_wpw', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_wpw_date'), channel_map={'no_supraventricular_arrhythmia_wpw':0, 'prevalent_supraventricular_arrhythmia_wpw':1, 'incident_supraventricular_arrhythmia_wpw':2}, loss=weighted_crossentropy([1.0, 710, 920], 'supraventricular_arrhythmia_wpw_prevalent_incident'))
supraventricular_arrhythmia_wpw_v2_prevalent_incident = TensorMap('supraventricular_arrhythmia_wpw_v2', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/supraventricular_arrhythmia_wpw_v2_date'), channel_map={'no_supraventricular_arrhythmia_wpw_v2':0, 'prevalent_supraventricular_arrhythmia_wpw_v2':1, 'incident_supraventricular_arrhythmia_wpw_v2':2}, loss=weighted_crossentropy([1.0, 721, 920], 'supraventricular_arrhythmia_wpw_v2_prevalent_incident'))
tricuspid_regurgitation_prevalent_incident = TensorMap('tricuspid_regurgitation', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/tricuspid_regurgitation_date'), channel_map={'no_tricuspid_regurgitation':0, 'prevalent_tricuspid_regurgitation':1, 'incident_tricuspid_regurgitation':2}, loss=weighted_crossentropy([1.0, 1829, 422], 'tricuspid_regurgitation_prevalent_incident'))
tricuspid_stenosis_prevalent_incident = TensorMap('tricuspid_stenosis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/tricuspid_stenosis_date'), channel_map={'no_tricuspid_stenosis':0, 'prevalent_tricuspid_stenosis':1, 'incident_tricuspid_stenosis':2}, loss=weighted_crossentropy([1.0, 37497, 37497], 'tricuspid_stenosis_prevalent_incident'))
tricuspid_valve_disease_prevalent_incident = TensorMap('tricuspid_valve_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/tricuspid_valve_disease_date'), channel_map={'no_tricuspid_valve_disease':0, 'prevalent_tricuspid_valve_disease':1, 'incident_tricuspid_valve_disease':2}, loss=weighted_crossentropy([1.0, 529, 119], 'tricuspid_valve_disease_prevalent_incident'))
ulcerative_colitis_prevalent_incident = TensorMap('ulcerative_colitis', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ulcerative_colitis_date'), channel_map={'no_ulcerative_colitis':0, 'prevalent_ulcerative_colitis':1, 'incident_ulcerative_colitis':2}, loss=weighted_crossentropy([1.0, 47, 165], 'ulcerative_colitis_prevalent_incident'))
uterine_fibroids_prevalent_incident = TensorMap('uterine_fibroids', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/uterine_fibroids_date'), channel_map={'no_uterine_fibroids':0, 'prevalent_uterine_fibroids':1, 'incident_uterine_fibroids':2}, loss=weighted_crossentropy([1.0, 9, 47], 'uterine_fibroids_prevalent_incident'))
valve_disease_prevalent_incident = TensorMap('valve_disease', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/valve_disease_date'), channel_map={'no_valve_disease':0, 'prevalent_valve_disease':1, 'incident_valve_disease':2}, loss=weighted_crossentropy([1.0, 53, 34], 'valve_disease_prevalent_incident'))
valvular_disease_unspecified_prevalent_incident = TensorMap('valvular_disease_unspecified', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/valvular_disease_unspecified_date'), channel_map={'no_valvular_disease_unspecified':0, 'prevalent_valvular_disease_unspecified':1, 'incident_valvular_disease_unspecified':2}, loss=weighted_crossentropy([1.0, 46, 789], 'valvular_disease_unspecified_prevalent_incident'))
venous_thromboembolism_prevalent_incident = TensorMap('venous_thromboembolism', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/venous_thromboembolism_date'), channel_map={'no_venous_thromboembolism':0, 'prevalent_venous_thromboembolism':1, 'incident_venous_thromboembolism':2}, loss=weighted_crossentropy([1.0, 12, 42], 'venous_thromboembolism_prevalent_incident'))
ventricular_arrhythmia_general_inclusive_definition_prevalent_incident = TensorMap('ventricular_arrhythmia_general_inclusive_definition', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ventricular_arrhythmia_general_inclusive_definition_date'), channel_map={'no_ventricular_arrhythmia_general_inclusive_definition':0, 'prevalent_ventricular_arrhythmia_general_inclusive_definition':1, 'incident_ventricular_arrhythmia_general_inclusive_definition':2}, loss=weighted_crossentropy([1.0, 159, 89], 'ventricular_arrhythmia_general_inclusive_definition_prevalent_incident'))
ventricular_arrhythmia_general_inclusive_definition_clinical_prevalent_incident = TensorMap('ventricular_arrhythmia_general_inclusive_definition_clinical', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ventricular_arrhythmia_general_inclusive_definition_clinical_date'), channel_map={'no_ventricular_arrhythmia_general_inclusive_definition_clinical':0, 'prevalent_ventricular_arrhythmia_general_inclusive_definition_clinical':1, 'incident_ventricular_arrhythmia_general_inclusive_definition_clinical':2}, loss=weighted_crossentropy([1.0, 180, 104], 'ventricular_arrhythmia_general_inclusive_definition_clinical_prevalent_incident'))
ventricular_arrhythmia_sudden_cardiac_death_prevalent_incident = TensorMap('ventricular_arrhythmia_sudden_cardiac_death', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ventricular_arrhythmia_sudden_cardiac_death_date'), channel_map={'no_ventricular_arrhythmia_sudden_cardiac_death':0, 'prevalent_ventricular_arrhythmia_sudden_cardiac_death':1, 'incident_ventricular_arrhythmia_sudden_cardiac_death':2}, loss=weighted_crossentropy([1.0, 402, 163], 'ventricular_arrhythmia_sudden_cardiac_death_prevalent_incident'))
ventricular_arrhythmia_ventricular_premature_depolarizations_prevalent_incident = TensorMap('ventricular_arrhythmia_ventricular_premature_depolarizations', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ventricular_arrhythmia_ventricular_premature_depolarizations_date'), channel_map={'no_ventricular_arrhythmia_ventricular_premature_depolarizations':0, 'prevalent_ventricular_arrhythmia_ventricular_premature_depolarizations':1, 'incident_ventricular_arrhythmia_ventricular_premature_depolarizations':2}, loss=weighted_crossentropy([1.0, 1271, 503], 'ventricular_arrhythmia_ventricular_premature_depolarizations_prevalent_incident'))
ventricular_arrhythmia_vt_prevalent_incident = TensorMap('ventricular_arrhythmia_vt', Interpretation.CATEGORICAL,  storage_type=StorageType.CATEGORICAL_FLAG, path_prefix='categorical', tensor_from_file=prevalent_incident_tensor('dates/enroll_date', 'dates/ventricular_arrhythmia_vt_date'), channel_map={'no_ventricular_arrhythmia_vt':0, 'prevalent_ventricular_arrhythmia_vt':1, 'incident_ventricular_arrhythmia_vt':2}, loss=weighted_crossentropy([1.0, 295, 208], 'ventricular_arrhythmia_vt_prevalent_incident'))



import os
import re
import logging
from typing import Dict, Tuple, Callable

import h5py
import numpy as np

from ml4h.defines import TENSOR_EXT
from ml4h.tensormap.general import get_tensor_at_first_date


def token_dictionary_and_text_from_file(
        text_file: str,
        remove_special_chars: bool = True,
) -> Tuple[str, Dict[str, int]]:
    texts = []
    characters = set()
    with open(text_file) as file:
        for i, line in enumerate(file.readlines()):
            cur_line = _preprocess_sentence(line, remove_special_chars)
            [characters.add(char) for char in cur_line]
            texts.append(cur_line)
            if i % 50000 == 0:
                logging.info(f'Read {i} lines from {text_file}')
    logging.info(f'Total characters: {len(characters)}')
    char2index = dict((c, i) for i, c in enumerate(sorted(list(characters))))
    index2char = dict((i, c) for i, c in enumerate(sorted(list(characters))))
    logging.info(f'char2index:\n\n {char2index}  \n\n\n\n index2char: \n\n {index2char} \n\n\n')
    return ''.join(texts), char2index


def token_dictionary_from_hd5_key(
        tensors: str,
        path_prefix: str,
        name: str,
) -> Dict[str, int]:
    characters = set()
    for i, tp in enumerate(os.listdir(tensors)):
        if os.path.splitext(tp)[-1].lower() != TENSOR_EXT:
            continue
        if i % 400 == 0:
            logging.debug(f'Found {len(characters)} unique tokens in {i} HD5 files at:{tensors}')
        if i > 2000:
            break
        with h5py.File(tensors + tp, 'r') as hd5:
            if name in hd5[path_prefix]:
                characters.update(np.unique(get_tensor_at_first_date(hd5, path_prefix, name)))

    logging.info(f'Total characters from HD5 Tensor {path_prefix} and name {name}: {len(characters)}')
    char2index = dict((c, i) for i, c in enumerate(sorted(list(characters))))
    logging.info(f'char2index:\n {char2index} \n')
    return char2index


def random_text_window_tensor(
    text: str,
    window_size: int,
) -> Callable:
    def text_from_file(tm, _, dependents={}):
        tensor = np.zeros(tm.shape, dtype=np.float32)
        random_index = np.random.randint(window_size, len(text)-window_size)
        for i, c in enumerate(text[random_index:random_index+window_size]):
            tensor[i] = tm.channel_map[c]
        if tm.dependent_map is not None:
            start_next_window = random_index + 1
            dependents[tm.dependent_map] = np.zeros(tm.dependent_map.shape, dtype=np.float32)
            for j, c in enumerate(text[start_next_window:start_next_window + tm.dependent_map.shape[0]]):
                dependents[tm.dependent_map][j] = tm.dependent_map.channel_map[c]
        return tensor
    return text_from_file


def _preprocess_sentence(sentence, remove_special_chars):
    sentence = sentence.strip()
    if remove_special_chars:
        #replacing everything with space except (a-z, A-Z, ".", "?", "!", ",")
        sentence = re.sub(r"[^a-zA-Z?.!,]+", " ", sentence)
        sentence = sentence.strip()
    return sentence


def random_array_window_tensors(
    window_shape: Tuple[int],
    shift_axis: int = 0,
) -> Callable:
    def window_as_text_from_file(tm, hd5, dependents={}):
        full_tensor = get_tensor_at_first_date(hd5, tm.path_prefix, tm.name)
        indexes = [np.random.randint(window_shape[i], edge-window_shape[i]) for i, edge in enumerate(full_tensor.shape)]
        random_window = tuple(slice(index-window_shape[i], index) for i, index in enumerate(indexes))
        next_window = tuple(
            slice((index + 1 if i == shift_axis else index)-window_shape[i], index + 1 if i == shift_axis else index) for i, index in enumerate(indexes)
        )
        tensor = full_tensor[random_window].flatten()
        if tm.dependent_map is not None:
            dependents[tm.dependent_map] = np.zeros(tm.dependent_map.shape, dtype=np.float32)
            flat = full_tensor[next_window].flatten()
            for j, c in enumerate(flat):
                dependents[tm.dependent_map][j] = tm.dependent_map.channel_map[c]
        return tensor
    return window_as_text_from_file



# Training models built by the model factory

import os
import logging
from typing import List, Tuple, Iterable, Union

from tensorflow.keras.callbacks import History
from tensorflow.keras.models import Model, load_model
from tensorflow.keras.callbacks import ModelCheckpoint, EarlyStopping, ReduceLROnPlateau, Callback

from ml4h.TensorMap import TensorMap
from ml4h.plots import plot_metric_history
from ml4h.defines import IMAGE_EXT, MODEL_EXT
from ml4h.models.inspect import plot_and_time_model
from ml4h.models.model_factory import get_custom_objects


def train_model_from_generators(
    model: Model,
    generate_train: Iterable,
    generate_valid: Iterable,
    training_steps: int,
    validation_steps: int,
    batch_size: int,
    epochs: int,
    patience: int,
    output_folder: str,
    run_id: str,
    inspect_model: bool,
    inspect_show_labels: bool,
    output_tensor_maps: List[TensorMap] = [],
    return_history: bool = False,
    plot: bool = True,
    save_last_model: bool = False,
) -> Union[Model, Tuple[Model, History]]:
    """Train a model from tensor generators for validation and training data.

    Training data lives on disk, it will be loaded by generator functions.
    Plots the metric history after training. Creates a directory to save weights, if necessary.
    Measures runtime and plots architecture diagram if inspect_model is True.
    :param model: The model to optimize
    :param generate_train: Generator function that yields mini-batches of training data.
    :param generate_valid: Generator function that yields mini-batches of validation data.
    :param training_steps: Number of mini-batches in each so-called epoch
    :param validation_steps: Number of validation mini-batches to examine after each epoch.
    :param batch_size: Number of training examples in each mini-batch
    :param epochs: Maximum number of epochs to run regardless of Early Stopping
    :param patience: Number of epochs to wait before reducing learning rate.
    :param output_folder: Directory where output file will be stored
    :param run_id: User-chosen string identifying this run
    :param inspect_model: If True, measure training and inference runtime of the model and generate architecture plot.
    :param inspect_show_labels: If True, show labels on the architecture plot.
    :param output_tensor_maps: List of output TensorMap
    :param return_history: If true return history from training and don't plot the training history
    :param plot: If true, plots the metrics for train and validation set at the end of each epoch
    :param save_last_model: If true saves the model weights from last epoch otherwise saves model with best validation loss

    :return: The optimized model.

    """
    model_file = os.path.join(output_folder, run_id, run_id + MODEL_EXT)
    if not os.path.exists(os.path.dirname(model_file)):
        os.makedirs(os.path.dirname(model_file))

    if inspect_model:
        image_p = os.path.join(output_folder, run_id, 'architecture_graph_' + run_id + IMAGE_EXT)
        plot_and_time_model(model, generate_train, generate_valid, batch_size, training_steps, inspect_show_labels, image_p)

    history = model.fit(
        generate_train, steps_per_epoch=training_steps, epochs=epochs, verbose=1,
        validation_steps=validation_steps, validation_data=generate_valid,
        callbacks=_get_callbacks(patience, model_file, save_last_model),
    )

    logging.info('Model weights saved at: %s' % model_file)
    custom_dict = get_custom_objects(output_tensor_maps)
    model = load_model(model_file, custom_objects=custom_dict, compile=False)
    model.compile(optimizer='adam', loss='mse')
    if plot:
        plot_metric_history(history, training_steps, run_id, os.path.dirname(model_file))
    if return_history:
        return model, history
    return model


def _get_callbacks(
    patience: int, model_file: str, save_last_model: bool,
) -> List[Callback]:
    callbacks = [
        EarlyStopping(monitor='val_loss', patience=patience * 3, verbose=1),
        ReduceLROnPlateau(monitor='val_loss', factor=0.5, patience=patience, verbose=1),
        ModelCheckpoint(filepath=model_file, verbose=1, save_best_only=not save_last_model),
    ]
    
    return callbacks



import os
import numpy as np
import pandas as pd
from typing import Optional
from tensorflow.keras import optimizers
from tensorflow.keras import backend as K
from tensorflow.keras.models import Model
from tensorflow_addons.optimizers import RectifiedAdam, TriangularCyclicalLearningRate, Triangular2CyclicalLearningRate

from ml4h.plots import plot_find_learning_rate
from ml4h.tensor_generators import TensorGenerator


def get_optimizer(name: str, learning_rate: float, steps_per_epoch: int = None, learning_rate_schedule: str = None, optimizer_kwargs=None):
    if not optimizer_kwargs:
        optimizer_kwargs = {}
    name = str.lower(name)
    rate_or_schedule = _get_learning_rate_schedule(learning_rate, learning_rate_schedule, steps_per_epoch)
    try:
        opt = optimizers.get(name)
        opt.__init__(rate_or_schedule, **optimizer_kwargs)
        return opt
    except ValueError:
        pass
    if name in NON_KERAS_OPTIMIZERS:
        return NON_KERAS_OPTIMIZERS[name](rate_or_schedule, **optimizer_kwargs)
    raise ValueError(f'Unknown optimizer {name}.')


def _get_learning_rate_schedule(learning_rate: float, learning_rate_schedule: str = None, steps_per_epoch: int = None):
    if learning_rate_schedule is None:
        return learning_rate
    if learning_rate_schedule == 'triangular':
        return TriangularCyclicalLearningRate(
            initial_learning_rate=learning_rate / 5, maximal_learning_rate=learning_rate,
            step_size=steps_per_epoch * 5,
        )
    if learning_rate_schedule == 'triangular2':
        return Triangular2CyclicalLearningRate(
            initial_learning_rate=learning_rate / 5, maximal_learning_rate=learning_rate,
            step_size=steps_per_epoch * 5,
        )
    else:
        raise ValueError(f'Learning rate schedule "{learning_rate_schedule}" unknown.')


NON_KERAS_OPTIMIZERS = {
    'radam': RectifiedAdam,
}


def find_learning_rate(model: Model, generate_train: TensorGenerator, steps: int, output_folder: str = None) -> Optional[float]:
    """
    Finds the learning rate for the model that will decrease the loss most quickly.
    Recommended to set batch size as large as possible.
    If output_folder provided, then plot and csv will be generated.
    Based on https://sgugger.github.io/how-do-you-find-a-good-learning-rate.html
    """
    beta = .98  # parameter for smoothing of loss. Larger is more smooth.
    lrs = np.geomspace(1e-7, 1e2, steps)
    avg_loss = 0
    best_loss = np.inf
    optimizer = model.optimizer
    losses, smoothed_losses = [], []
    for i, lr in enumerate(lrs):
        K.set_value(optimizer.learning_rate, lr)
        history = model.fit(generate_train, verbose=0, steps_per_epoch=2, epochs=2)
        loss = history.history['loss'][0]
        losses.append(loss)
        avg_loss = beta * avg_loss + (1 - beta) * loss
        smoothed_loss = avg_loss / (1 - beta**(i + 1))
        smoothed_losses.append(smoothed_loss)
        best_loss = min(best_loss, smoothed_loss)
        if smoothed_loss > 2 * best_loss:
            break
    best_lr = _choose_best_learning_rate(np.array(smoothed_losses), lrs)
    if output_folder:
        pd.DataFrame({'loss': losses, 'learning_rate': lrs[:len(losses)], 'smoothed_loss': smoothed_losses, 'picked_lr': best_lr}).to_csv(os.path.join(output_folder, 'find_learning_rate.csv'), index=False)
        plot_find_learning_rate(
            learning_rates=lrs[:len(losses)], losses=losses, smoothed_losses=smoothed_losses, picked_learning_rate=best_lr,
            figure_path=output_folder,
        )
    return best_lr


def _choose_best_learning_rate(smoothed_loss: np.ndarray, lr: np.ndarray) -> float:
    burn_in = len(lr) // 10
    best_delta = -np.inf
    best_lr = None
    mean_width = 4
    for i in range(burn_in, len(smoothed_loss)):
        if smoothed_loss[i - 1] > smoothed_loss[0]:
            continue  # loss delta from previously high loss should be ignored
        delta = smoothed_loss[i - mean_width - 1: i - 1].mean() - smoothed_loss[i - mean_width: i].mean()  # positive is good, means loss decreased a lot
        if delta > best_delta:
            best_delta = delta
            best_lr = lr[i]
    return float(best_lr) if best_lr else None
